==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lximage-qt/lximage-qt_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../../application.cpp" line="89"/>
        <source>Take a screenshot</source>
        <translation>Schermafdruk maken</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="93"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[Bestand1, Bestand2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="148"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="149"/>
        <source>LXImage - a simple and fast image viewer

Copyright (C) 2013
LXDE Project: http://lxde.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>LXImage - eeen eenvoudige en snelle afbeeldingkijker

Auteursrecht (C) 2013
LXDE project: http://lxde.org/

Auteur:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="242"/>
        <source>Open File</source>
        <translation>Bestand openen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="243"/>
        <location filename="../../mainwindow.cpp" line="264"/>
        <source>Image files (%1)</source>
        <translation>Afbeeldingbestanden (%1)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="264"/>
        <source>Save File</source>
        <translation>Bestand opslaan</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="530"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Laden...) - Afbeeldingkijker</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="535"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Laden ist fehlgeschlagen) - Bildbetrachter</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="539"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Afbeeldingkijker</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="576"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Afbeeldingkijker</translation>
    </message>
    <message>
        <source>%1 (Loading...) - Image Viewer</source>
        <translation type="vanished">%1 (Laden...) - Afbeeldingkijker</translation>
    </message>
    <message>
        <source>%1 (Failed to Load) - Image Viewer</source>
        <translation type="vanished">%1 (Fout bij het laden) - Afbeeldingkijker</translation>
    </message>
    <message>
        <source>%1 (%2x%3) - Image Viewer</source>
        <translation type="vanished">%1 (%2x%3) - Afbeeldingkijker</translation>
    </message>
    <message>
        <source>Image Viewer</source>
        <translation type="vanished">Afbeeldingkijker</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="819"/>
        <source>Thumbnails</source>
        <translation>Miniaturen</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Afbeeldingkijker</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="159"/>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="169"/>
        <source>&amp;Open File</source>
        <translatorcomment>This should be &quot;&amp;Open&quot; (without &quot;File&quot;) imho. We are in the File menu.</translatorcomment>
        <translation>Bestand &amp;openen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="172"/>
        <source>Ctrl+O</source>
        <translatorcomment>Shortcuts are translated automatically. No need to manually translate it to &quot;Strg+O&quot;.</translatorcomment>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="182"/>
        <source>&amp;Save</source>
        <translation>&amp;Opslaan</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="185"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="195"/>
        <source>Save &amp;As</source>
        <translation>Opslaan &amp;als</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="198"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="208"/>
        <source>&amp;Close</source>
        <translation>S&amp;luiten</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="211"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="221"/>
        <source>Zoom &amp;In</source>
        <translation>Ver&amp;groten</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="224"/>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="234"/>
        <source>Zoom &amp;Out</source>
        <translation>Ver&amp;kleinen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="237"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="247"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>Kopieer naar &amp;klembord</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="257"/>
        <location filename="../../mainwindow.ui" line="260"/>
        <source>Next File</source>
        <translation>Volgende bestand</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="273"/>
        <location filename="../../mainwindow.ui" line="276"/>
        <source>Previous File</source>
        <translation>Vorige bestand</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="263"/>
        <source>PgDown</source>
        <translation>Omlaag</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="279"/>
        <source>PgUp</source>
        <translation>Omhoog</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="289"/>
        <source>Original Size</source>
        <translation>Oorspronkelijke grootte</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="299"/>
        <source>&amp;Fit</source>
        <translation>Passen&amp;d</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="309"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>Met de klok mee &amp;draaien</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="319"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>&amp;Tegen de klok in draaien</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="324"/>
        <source>P&amp;references</source>
        <translation>&amp;Voorkeuren</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="329"/>
        <source>&amp;Print</source>
        <translation>&amp;Afdrukken</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="332"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="342"/>
        <source>First File</source>
        <translation>Eerste bestand</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="345"/>
        <source>Home</source>
        <translation>Thuis</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="355"/>
        <source>Last File</source>
        <translation>Laatste bestand</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="358"/>
        <source>End</source>
        <translation>Einde</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="368"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nieuw venster</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="371"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="376"/>
        <source>Flip &amp;Horizontally</source>
        <translation>&amp;Horizontaal spiegelen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="386"/>
        <source>Capture Screenshot</source>
        <translation>Schermafdruk maken</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="394"/>
        <source>F&amp;ull Screen</source>
        <translation>&amp;Gesamter Bildschirm</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="397"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="402"/>
        <source>Flip &amp;Vertically</source>
        <translation>&amp;Verticaal spiegelen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="412"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Plakken vanuit klembord</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="425"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Diapresentatie</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="435"/>
        <source>&amp;Delete</source>
        <translation>&amp;Wissen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="438"/>
        <source>Del</source>
        <translation>Wis</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="446"/>
        <source>Show Thumbnails</source>
        <translation>Miniaturen tonen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="451"/>
        <source>File Properties</source>
        <translatorcomment>Translation of &apos;file&apos; skipped, it is redundant (this is the file menu).</translatorcomment>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="55"/>
        <source>&amp;File</source>
        <translation>&amp;Bestand</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="71"/>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="77"/>
        <source>Go</source>
        <translation>Ga naar</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="86"/>
        <source>&amp;View</source>
        <translation>&amp;Tonen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="100"/>
        <source>&amp;Edit</source>
        <translation>&amp;Bewerken</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="120"/>
        <source>Toolbar</source>
        <translation>Werkbalk</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Voorkeuren</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Pictogramthema:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>Normale achtergrondkleur:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>Schermvullende achtergrondkleur:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="71"/>
        <source>Slide show interval (seconds):</source>
        <translation>Tussenpoze voor diapresentatie (seconden):</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Schermafdruk</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="28"/>
        <source>Take a screenshot</source>
        <translation>Schermafdruk maken</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="35"/>
        <source>Region</source>
        <translation>Bereik</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="41"/>
        <source>Whole screen</source>
        <translation>Hele scherm</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="51"/>
        <source>Current window only</source>
        <translation>Alleen huidige venster</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="61"/>
        <source>Include mouse cursor</source>
        <translation>Inclusief muisaanwijzer</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="68"/>
        <source> seconds</source>
        <translation> Seconden</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="85"/>
        <source>Delay:</source>
        <translation>Vertraging:</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="95"/>
        <source>Include window title and frame</source>
        <translation>Inclusief venstertitel en rand</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lximage-qt/lximage-qt_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../../application.cpp" line="91"/>
        <source>Take a screenshot</source>
        <translation>Schermafdruk maken</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="95"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[Bestand1, Bestand2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="143"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="144"/>
        <source>LXImage - a simple and fast image viewer

Copyright (C) 2013
LXDE Project: http://lxde.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>LXImage - eeen eenvoudige en snelle afbeeldingkijker

Auteursrecht (C) 2013
LXDE project: http://lxde.org/

Auteur:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="253"/>
        <source>Open File</source>
        <translation>Bestand openen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="254"/>
        <location filename="../../mainwindow.cpp" line="281"/>
        <source>Image files (%1)</source>
        <translation>Afbeeldingbestanden (%1)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="260"/>
        <source>Open directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="281"/>
        <source>Save File</source>
        <translation>Bestand opslaan</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="537"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Laden...) - Afbeeldingkijker</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="542"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Laden ist fehlgeschlagen) - Bildbetrachter</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="546"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Afbeeldingkijker</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="582"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Afbeeldingkijker</translation>
    </message>
    <message>
        <source>%1 (Loading...) - Image Viewer</source>
        <translation type="vanished">%1 (Laden...) - Afbeeldingkijker</translation>
    </message>
    <message>
        <source>%1 (Failed to Load) - Image Viewer</source>
        <translation type="vanished">%1 (Fout bij het laden) - Afbeeldingkijker</translation>
    </message>
    <message>
        <source>%1 (%2x%3) - Image Viewer</source>
        <translation type="vanished">%1 (%2x%3) - Afbeeldingkijker</translation>
    </message>
    <message>
        <source>Image Viewer</source>
        <translation type="vanished">Afbeeldingkijker</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="842"/>
        <source>Thumbnails</source>
        <translation>Miniaturen</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Afbeeldingkijker</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="160"/>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="170"/>
        <source>&amp;Open File</source>
        <translatorcomment>This should be &quot;&amp;Open&quot; (without &quot;File&quot;) imho. We are in the File menu.</translatorcomment>
        <translation>Bestand &amp;openen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="173"/>
        <source>Ctrl+O</source>
        <translatorcomment>Shortcuts are translated automatically. No need to manually translate it to &quot;Strg+O&quot;.</translatorcomment>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="183"/>
        <source>&amp;Save</source>
        <translation>&amp;Opslaan</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="186"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="196"/>
        <source>Save &amp;As</source>
        <translation>Opslaan &amp;als</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="199"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="209"/>
        <source>&amp;Close</source>
        <translation>S&amp;luiten</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="212"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="222"/>
        <source>Zoom &amp;In</source>
        <translation>Ver&amp;groten</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation type="vanished">Ctrl++</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="235"/>
        <source>Zoom &amp;Out</source>
        <translation>Ver&amp;kleinen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="238"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="248"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>Kopieer naar &amp;klembord</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="258"/>
        <location filename="../../mainwindow.ui" line="261"/>
        <source>Next File</source>
        <translation>Volgende bestand</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="274"/>
        <location filename="../../mainwindow.ui" line="277"/>
        <source>Previous File</source>
        <translation>Vorige bestand</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="264"/>
        <source>PgDown</source>
        <translation>Omlaag</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="225"/>
        <source>Ctrl+=</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="280"/>
        <source>PgUp</source>
        <translation>Omhoog</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="290"/>
        <source>Original Size</source>
        <translation>Oorspronkelijke grootte</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="293"/>
        <source>Ctrl+0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="303"/>
        <source>&amp;Fit</source>
        <translation>Passen&amp;d</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="313"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>Met de klok mee &amp;draaien</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="323"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>&amp;Tegen de klok in draaien</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="328"/>
        <source>P&amp;references</source>
        <translation>&amp;Voorkeuren</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="333"/>
        <source>&amp;Print</source>
        <translation>&amp;Afdrukken</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="336"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="346"/>
        <source>First File</source>
        <translation>Eerste bestand</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="349"/>
        <source>Home</source>
        <translation>Thuis</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="359"/>
        <source>Last File</source>
        <translation>Laatste bestand</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="362"/>
        <source>End</source>
        <translation>Einde</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="372"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nieuw venster</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="375"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="380"/>
        <source>Flip &amp;Horizontally</source>
        <translation>&amp;Horizontaal spiegelen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="390"/>
        <source>Capture Screenshot</source>
        <translation>Schermafdruk maken</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="398"/>
        <source>F&amp;ull Screen</source>
        <translation>&amp;Gesamter Bildschirm</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="401"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="406"/>
        <source>Flip &amp;Vertically</source>
        <translation>&amp;Verticaal spiegelen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="416"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Plakken vanuit klembord</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="429"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Diapresentatie</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="439"/>
        <source>&amp;Delete</source>
        <translation>&amp;Wissen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="442"/>
        <source>Del</source>
        <translation>Wis</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="450"/>
        <source>Show Thumbnails</source>
        <translation>Miniaturen tonen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="455"/>
        <source>File Properties</source>
        <translatorcomment>Translation of &apos;file&apos; skipped, it is redundant (this is the file menu).</translatorcomment>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="463"/>
        <source>Open &amp;Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="466"/>
        <source>Ctrl+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="55"/>
        <source>&amp;File</source>
        <translation>&amp;Bestand</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="78"/>
        <source>Go</source>
        <translation>Ga naar</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="87"/>
        <source>&amp;View</source>
        <translation>&amp;Tonen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="101"/>
        <source>&amp;Edit</source>
        <translation>&amp;Bewerken</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="121"/>
        <source>Toolbar</source>
        <translation>Werkbalk</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Voorkeuren</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Pictogramthema:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>Normale achtergrondkleur:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>Schermvullende achtergrondkleur:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="71"/>
        <source>Slide show interval (seconds):</source>
        <translation>Tussenpoze voor diapresentatie (seconden):</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Schermafdruk</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Schermafdruk maken</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Bereik</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Hele scherm</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Alleen huidige venster</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Inclusief muisaanwijzer</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="74"/>
        <source> seconds</source>
        <translation> Seconden</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Vertraging:</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Inclusief venstertitel en rand</translation>
    </message>
</context>
</TS>
